// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.loghandler;

import java.io.PrintWriter;
import java.io.Serializable;
import java.io.StringWriter;

public class LogMessage implements Serializable
{
  private final String stackTrace;
  private final String category;
  private final String message;
  private final long timestamp;
  private final long threadID;
  
  public LogMessage(String category, String message)
  {
    this.category = category;
    this.message = message;
    stackTrace = createStackTrace();
    timestamp = System.currentTimeMillis();
    threadID = ThreadIdGenerator.getThreadId();
  }

  public String getCategory()
  {
    return category;
  }

  public String getMessage()
  {
    return message;
  }

  public String getStackTrace()
  {
    return stackTrace;
  }
  
  public long getTimestamp()
  {
    return timestamp;
  }
  
  public long getThreadID()
  {
    return threadID;
  }
  
  public String toString()
  {
    return "LogMessage[" + category + "," + message + "]";
  }
  
  private String createStackTrace()
  {
    Throwable t = new Throwable();
    
    // First, convert the Throwable's stack trace to a String
    StringWriter stringWriter = new StringWriter();
    PrintWriter printWriter = new PrintWriter(stringWriter);
    t.printStackTrace(printWriter);
    String s = stringWriter.toString();
    
    // Then skip the leading, uninteresting part
    int lastUninteresting = Math.max(s.lastIndexOf("at org.apache.log4j."),
        s.lastIndexOf("at performancemonster.")) + 1;
    return s.substring(s.indexOf('\n', lastUninteresting) + 1);
  }
}
