// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package perfmonstertest;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.SwingUtilities;
import javax.swing.UIManager;

public class LogGeneratorWithoutInstrumentation
{
  private JButton type1, type2, type3;

  public static void main(String[] args)
  {
    SwingUtilities.invokeLater(new Runnable()
    {
      public void run()
      {
        LogGeneratorWithoutInstrumentation generator =
          new LogGeneratorWithoutInstrumentation();
        generator.createAndShowGUI();
      }
    });
  }

  private void createAndShowGUI()
  {
    try {
      UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
    } catch (Exception e) {
      e.printStackTrace();
    }

    // Create and set up the window.
    JFrame frame = new JFrame("LogGenerator");
    frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

    Action type1Action = new AbstractAction("Type1")
    {
      public void actionPerformed(ActionEvent evt)
      {
        Runnable r = new Runnable()
        {
          public void run()
          {
            heavyMethod1();
          }
        };
        new Thread(r).start();
      }
    };
    Action type2Action = new AbstractAction("Type2")
    {
      public void actionPerformed(ActionEvent evt)
      {
        Runnable r = new Runnable()
        {
          public void run()
          {
            heavyMethod2();
          }
        };
        new Thread(r).start();
      }
    };
    Action type3Action = new AbstractAction("Type3")
    {
      public void actionPerformed(ActionEvent evt)
      {
        Runnable r = new Runnable()
        {
          public void run()
          {
            heavyMethod3();
          }
        };
        new Thread(r).start();
      }
    };

    type1 = new JButton(type1Action);
    type2 = new JButton(type2Action);
    type3 = new JButton(type3Action);

    JPanel controls = new JPanel();
    controls.setLayout(new BoxLayout(controls, BoxLayout.PAGE_AXIS));
    controls.add(type1);
    controls.add(type2);
    controls.add(type3);

    frame.add(controls);

    // Display the window.
    frame.pack();
    frame.setVisible(true);
  }
  
  private void heavyMethod1()
  {
    try {
      Thread.sleep(1000);
    } catch (InterruptedException e) {
      e.printStackTrace();
    }
  }

  private void heavyMethod2()
  {
    try {
      Thread.sleep(2000);
    } catch (InterruptedException e) {
      e.printStackTrace();
    }
  }

  private void heavyMethod3()
  {
    try {
      Thread.sleep(3000);
    } catch (InterruptedException e) {
      e.printStackTrace();
    }
  }
}
