// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.agent.impl;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.lang.instrument.Instrumentation;
import java.net.ServerSocket;
import java.net.Socket;

import performancemonster.agent.AgentCommand;

public class AgentServer extends Thread
{
  private final ServerSocket serverSocket;
  private final Instrumentation instrumentation;

  public AgentServer(int port, Instrumentation instrumemtation)
      throws IOException
  {
    setDaemon(true);
    serverSocket = new ServerSocket(port);
    this.instrumentation = instrumemtation;
  }

  /** Listens for client connections * */
  public void run()
  {
    try {
      while (true) {
        System.out.println("Waiting for a connection");
        final Socket client = serverSocket.accept();
        System.out.println("Got a connection from "
            + client.getInetAddress().getHostName());
        ObjectInputStream ois = new ObjectInputStream(client
            .getInputStream());
        AgentCommand command = null;
        try {
          command = (AgentCommand) ois.readObject();
        } catch (ClassNotFoundException e) {
          e.printStackTrace();
        } finally {
          ois.close();
          client.close();
        }
        try {
          command.execute(instrumentation);
        } catch (Exception e) {
          System.out.println("Exception while executing command");
          e.printStackTrace();
        }
      }
    } catch (IOException e) {
      e.printStackTrace();
    }
  }
}
