package performancemonster.external;

import java.awt.Color;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Unmarshaller;

import org.apache.log4j.Logger;

import performancemonster.external.exceptions.ExternalException;
import performancemonster.graph.coloring.ColorRule;
import performancemonster.graph.coloring.Colorer;
import performancemonster.schemas.colors.Graphcolors;
import performancemonster.schemas.colors.RuleType;

public class ColorImporter
{
  private static final Logger logger = Logger.getLogger(GraphImporter.class);

  private final Colorer colorer;

  public ColorImporter(Colorer colorer)
  {
    this.colorer = colorer;
  }

  public void importFromFile(File file) throws ExternalException
  {
    try {
      JAXBContext context = JAXBContext
          .newInstance("performancemonster.schemas.colors");
      Unmarshaller unmarshaller = context.createUnmarshaller();

      Graphcolors graphElements = (Graphcolors) unmarshaller
          .unmarshal(new FileInputStream(file));

      // Create a template colorer
      Colorer newColorer = new Colorer();
      newColorer.setBackgroundColor(convertFromString(graphElements
          .getBackground()));
      newColorer.setDefaultBarColor(convertFromString(graphElements
          .getDefaultBar()));
      newColorer.setDefaultBorderColor(convertFromString(graphElements
          .getDefaultBorder()));

      for (Object o : graphElements.getRule()) {
        RuleType ruleType = (RuleType) o;
        ColorRule rule = new ColorRule(ruleType.getName());
        rule.setBarColor(convertFromString(ruleType.getBar()));
        rule.setBorderColor(convertFromString(ruleType.getBorder()));
        if (ruleType.getCategory() != null) {
          rule.setCategory(ruleType.getCategory());
        }
        if (ruleType.getMessage() != null) {
          rule.setMessage(ruleType.getMessage());
        }
        if (ruleType.getStackTrace() != null) {
          rule.setStackTrace(ruleType.getStackTrace());
        }
        newColorer.appendColorRule(rule);
      }

      colorer.replaceWith(newColorer);
    } catch (JAXBException e) {
      String errorString = "Could not import data from file " + file;
      logger.error(errorString, e);
      throw new ExternalException(errorString, e);
    } catch (FileNotFoundException e) {
      String errorString = "Could not import data from file " + file;
      logger.error(errorString, e);
      throw new ExternalException(errorString, e);
    }
  }

  private Color convertFromString(String s) throws ExternalException
  {
    if (!s.startsWith("#")) {
      throw new ExternalException("Color value \"" + s
          + "\" does not begin with #");
    }
    if (s.length() != 7) {
      throw new ExternalException("Color value \"" + s
          + "\" is not of correct size");
    }
    int i;
    try {
      i = Integer.parseInt(s.substring(1), 16);
    } catch (NumberFormatException e) {
      throw new ExternalException("Color value \"" + s
          + "\" could not be parsed as a hexadecimal color value");
    }
    int red = (i & 0xFF0000) >> 16;
    int green = (i & 0x00FF00) >> 8;
    int blue = i & 0x0000FF;
    return new Color(red, green, blue);
  }
}
