package performancemonster.external;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Unmarshaller;

import org.apache.log4j.Logger;

import performancemonster.external.exceptions.ExternalException;
import performancemonster.graph.GraphElement;
import performancemonster.graph.GraphModel;
import performancemonster.schemas.graph.GraphElementType;
import performancemonster.schemas.graph.Graphelements;

public class GraphImporter
{
  private static final Logger logger = Logger.getLogger(GraphImporter.class);

  private final GraphModel model;

  public GraphImporter(GraphModel model)
  {
    this.model = model;
  }

  public void importFromFile(File file) throws ExternalException
  {
    try {
      JAXBContext context = JAXBContext
          .newInstance("performancemonster.schemas.graph");
      Unmarshaller unmarshaller = context.createUnmarshaller();

      Graphelements graphElements = (Graphelements) unmarshaller
          .unmarshal(new FileInputStream(file));

      // Clear the existing model
      model.clear();

      for (Object o : graphElements.getGraphelement()) {
        GraphElementType elementType = (GraphElementType) o;
        model.putElement(createGraphElement(elementType.getCategory(),
            elementType.getMessage(), elementType.getStackTrace(), elementType
                .getStartTime().longValue(), elementType.getEndTime()
                .longValue()));
      }
    } catch (JAXBException e) {
      String errorString = "Could not import data from file " + file;
      logger.error(errorString, e);
      throw new ExternalException(errorString, e);
    } catch (FileNotFoundException e) {
      String errorString = "Could not import data from file " + file;
      logger.error(errorString, e);
      throw new ExternalException(errorString, e);
    }
  }

  private GraphElement createGraphElement(final String category,
      final String message, final String stackTrace, final long beginning,
      final long end)
  {
    return new GraphElement()
    {
      public String getCategory()
      {
        return category;
      }

      public String getMessage()
      {
        return message;
      }

      public String getStackTrace()
      {
        return stackTrace;
      }

      public long getBeginning()
      {
        return beginning;
      }

      public long getEnd()
      {
        return end;
      }
    };
  }
}
