package performancemonster.graph;

import java.util.Collections;
import java.util.Comparator;
import java.util.Set;
import java.util.SortedSet;
import java.util.TreeSet;


public class GraphModel
{
  private static final Comparator<GraphElement> comparator = new GraphElementComparator();
  private SortedSet<GraphElement> elements;
  
  public GraphModel()
  {
    elements = new TreeSet<GraphElement>(comparator);
  }
  
  public void clear()
  {
    elements.clear();
  }
  
  public void removeElement(GraphElement element)
  {
    elements.remove(element);
  }
  
  public void putElement(GraphElement element)
  {
    elements.add(element);
  }
    
  public Set<GraphElement> getElements()
  {
    return Collections.unmodifiableSet(elements);
  }
  
  private static class GraphElementComparator implements Comparator<GraphElement>
  {
    public int compare(GraphElement e1, GraphElement e2)
    {
      long beginDiff = e1.getBeginning() - e2.getBeginning();
      if (beginDiff > 0) {
        return 1;
      } else if (beginDiff < 0) {
        return -1;
      }
      
      long endDiff = e1.getEnd() - e2.getEnd();
      if (endDiff > 0) {
        return -1;
      } else if (endDiff < 0) {
        return 1;
      }

      int messageDiff = e1.getMessage().compareTo(e2.getMessage());
      if (messageDiff != 0) {
        return messageDiff;
      }

      int stackTraceDiff = e1.getStackTrace().compareTo(e2.getStackTrace());
      if (stackTraceDiff !=0) {
        return stackTraceDiff;
      }

      return 0;
    }
  }
}
