// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.helpers;

import java.util.*;

/**
 * A map from objects to {@link java.util.Set}s of objects.
 * 
 * @param <K>
 *          The key type.
 * @param <V>
 *          The value type.
 */
public class SetMap<K, V>
{
  private Map<K, Set<V>> map;

  /**
   * Constructs an empty {@link SetMap}.
   */
  public SetMap()
  {
    map = new HashMap<K, Set<V>>();
  }

  public synchronized void put(K key, V value)
  {
    Set<V> values = map.get(key);
    if (values == null) {
      values = new HashSet<V>();
      map.put(key, values);
    }
    values.add(value);
  }

  public synchronized Set<V> get(K key)
  {
    Set<V> values = map.get(key);
    if (values == null) {
      return Collections.emptySet();
    } else {
      return values;
    }
  }

  public synchronized void remove(K key)
  {
    map.remove(key);
  }

  public synchronized void removeValue(K key, V value)
  {
    Set<V> values = map.get(key);
    if (values != null) {
      values.remove(value);
      if (values.isEmpty()) {
        map.remove(key);
      }
    }
  }
  
  public synchronized boolean containsKey(K key)
  {
    return map.containsKey(key);
  }
}
