// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.instrumentation.impl;

import java.io.Serializable;
import java.lang.instrument.Instrumentation;
import java.net.InetAddress;
import java.net.UnknownHostException;

import performancemonster.agent.Agent;
import performancemonster.agent.AgentCommand;
import performancemonster.helpers.SystemProperties;
import performancemonster.instrumentation.exceptions.InstrumentationException;
import performancemonster.loghandler.LogSender;

public class InitializeCommand implements AgentCommand, Serializable
{
  private final String hostName;
  private final int port;
  
  public InitializeCommand() throws InstrumentationException
  {
    // This constructor is run in the VM of PerformanceMonster, so we need to
    // capture the hostname and port number for PerformanceMonster
    port = SystemProperties.getInstance().getPortNumber();
    try {
      hostName = InetAddress.getLocalHost().getHostAddress();
    } catch (UnknownHostException e) {
      throw new InstrumentationException("Problems finding host name", e);
    }
  }
  
  public void execute(Instrumentation inst)
  {
    LogSender sender = new LogSender();
    sender.setRemoteHost(hostName);
    sender.setPort(port);
    sender.connect();
    Agent.sender = sender;
  }
  
  public String toString()
  {
    return "InitializeCommand[" + hostName + "," + port + "]";
  }
}
