package performancemonster.presentation.graphelement;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.WindowConstants;

import performancemonster.graph.GraphElement;

public class GraphElementFrame extends JFrame
{
  public GraphElementFrame(GraphElement element)
  {
    super("Graph element");
    GridBagLayout layout = new GridBagLayout();
    setLayout(layout);
    GridBagConstraints c = new GridBagConstraints();

    setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
    
    c.insets = new Insets(2, 2, 2, 2);
    c.anchor = GridBagConstraints.NORTHWEST;
    int line = 0;

    prepareNewLine(c, line++, false);
    addLabel("Time:", c);
    prepareNextPart(c, 1, 1, false, 1);
    addLabel((element.getEnd() - element.getBeginning()) + " ms", c);

    prepareNewLine(c, line++, false);
    addLabel("Category:", c);
    prepareNextPart(c, 1, 1, false, 1);
    addLabel(element.getCategory(), c);

    prepareNewLine(c, line++, false);
    addLabel("Message:", c);
    prepareNextPart(c, 1, 0, false, 1);
    addLabel(element.getMessage(), c);

    prepareNewLine(c, line++, true);
    addLabel("Stack trace:", c);
    prepareNextPart(c, 1, 0, true, 1);
    JTextArea stackTrace = new JTextArea(element.getStackTrace());
    stackTrace.setEditable(false);
    add(new JScrollPane(stackTrace), c);

    prepareNewLine(c, line++, false);
    prepareNextPart(c, 0, 1, false, 2);
    JButton ok = new JButton(new AbstractAction("OK") {
      public void actionPerformed(ActionEvent e)
      {
        dispose();
      }
    });
    add(ok, c);

    pack();
    ok.requestFocusInWindow();
    setVisible(true);
  }

  private void prepareNewLine(GridBagConstraints c, int y, boolean resize)
  {
    c.gridx = 0;
    c.gridy = y;
    c.weightx = 0;
    c.weighty = resize ? 1 : 0;
    c.fill = resize ? GridBagConstraints.VERTICAL : GridBagConstraints.NONE;
    c.gridwidth = 1;
  }

  private void prepareNextPart(GridBagConstraints c, int x, double weightx,
      boolean resize, int width)
  {
    c.gridx = x;
    c.weightx = weightx;
    c.weighty = resize ? 1 : 0;
    c.fill = resize ? GridBagConstraints.BOTH : GridBagConstraints.HORIZONTAL;
    c.gridwidth = width;
  }

  private void addLabel(String text, GridBagConstraints c)
  {
    add(new JLabel(text), c);
  }
}
