// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.presentation.helpers;

import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.io.PrintWriter;
import java.io.StringWriter;

import javax.swing.*;

public class Dialogs
{
  private final static Dialogs INSTANCE = new Dialogs();
  private final static String ERROR_OVERVIEW = "An error occured while executing an operation. Check the logs for further information.";

  private Dialogs()
  {
    // Intentionally left blank
  }

  public static Dialogs getInstance()
  {
    return INSTANCE;
  }

  public void showError(Frame owner, String text, Throwable cause)
  {
    final JDialog dialog = new JDialog(owner, true);

    Action closeAction = new AbstractAction("Close")
    {
      public void actionPerformed(ActionEvent evt)
      {
        dialog.dispose();
      }
    };

    // Write the full stack trace to a string
    StringWriter stringWriter = new StringWriter();
    PrintWriter printWriter = new PrintWriter(stringWriter);
    cause.printStackTrace(printWriter);
    String stackTrace = "<html>"
        + stringWriter.getBuffer().toString().replaceAll("\n", "<br>\n")
        + "</html>";

    LayoutManagerHandler layouter = new LayoutManagerHandler(
        LayoutManagerHandler.Direction.VERTICAL);
    layouter.addComponent(new JLabel(ERROR_OVERVIEW), false, 0.0);
    layouter.addComponent(new JLabel(text), false, 0.0);
    layouter.addComponent(new JScrollPane(new JLabel(stackTrace)), true, 1.0);
    layouter.addComponent(new JButton(closeAction), false, 0.0);

    dialog.add(layouter.getPanel());
    dialog.pack();
    dialog.setVisible(true);
  }
  
  public boolean showYesNo(Frame owner, String text, String title, String yes,
      String no)
  {
    Object[] options = { yes, no };
    int n = JOptionPane.showOptionDialog(owner, text, title,
        JOptionPane.YES_NO_OPTION, JOptionPane.QUESTION_MESSAGE, null, options,
        options[1]);
    return n == 0;
  }

}
