// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.presentation.instrumentation.impl.panels;

import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.util.Set;

import javax.swing.JList;
import javax.swing.JScrollPane;

import performancemonster.instrumentation.InstrumentationFacade;
import performancemonster.instrumentation.InstrumentationListener;
import performancemonster.instrumentation.settings.Setting;
import performancemonster.presentation.instrumentation.impl.InstrumentedListModel;

public class InstrumentedList implements InstrumentationListener
{
  private final InstrumentedListModel instrumentedListModel;
  private final JList instrumentedList;

  public InstrumentedList(InstrumentationFacade instrumentation,
      final InstrumentationSelection instrumentationSelection)
  {
    instrumentedListModel = new InstrumentedListModel();
    instrumentedList = new JList(instrumentedListModel);
    MouseListener instrumentedListMouseListener = new MouseAdapter()
    {
      public void mouseClicked(MouseEvent e)
      {
        // When the user clicks on an instrumented method, it should be shown
        // in the package tree
        int index = instrumentedList.locationToIndex(e.getPoint());
        Setting setting = instrumentedListModel
            .getElementAt(index);
        instrumentationSelection.showSetting(setting);
      }
    };
    instrumentedList.addMouseListener(instrumentedListMouseListener);

    instrumentation.addListener(this);
  }
  
  public void setSelectedSetting(Setting setting)
  {
    if (instrumentedListModel.contains(setting)) {
      instrumentedList.setSelectedValue(setting, true);
    } else {
      instrumentedList.clearSelection();
    }
  }

  public int[] getSelectedIndices()
  {
    return instrumentedList.getSelectedIndices();
  }

  public Setting getElementAt(int i)
  {
    return instrumentedListModel.getElementAt(i);
  }

  public int getSize()
  {
    return instrumentedListModel.getSize();
  }

  public JScrollPane createPanel()
  {
    return new JScrollPane(instrumentedList);
  }

  public void settingsAdded(Set<Setting> addedSettings)
  {
    instrumentedListModel.addSettings(addedSettings);
  }

  public void settingsRemoved(Set<Setting> removedSettings)
  {
    instrumentedListModel.removeSettings(removedSettings);
  }
}
