package performancemonster.test.external;

import java.awt.Color;
import java.io.File;

import junit.framework.TestCase;
import performancemonster.external.ColorImporter;
import performancemonster.graph.coloring.ColorRule;
import performancemonster.graph.coloring.Colorer;

/**
 * Tests {@link ColorImporter}. Does so by reading files generated by running
 * {@link ColorExportTest}.
 */
public class ColorImportTest extends TestCase
{
  /**
   * Imports a colorer with no rules.
   */
  public void testColorImportNoRules() throws Exception
  {
    File file = new File("test/ColorImportTest_NoRules.xml");
    Colorer colorer = new Colorer();
    ColorImporter importer = new ColorImporter(colorer);
    importer.importFromFile(file);

    assertEquals("Wrong number of rules", 0, colorer.getNumberOfRules());
    assertEquals("Wrong background color", new Color(0xFF, 0xAB, 0x10), colorer
        .getBackgroundColor());
    assertEquals("Wrong default bar color", new Color(0, 1, 2), colorer
        .getDefaultBarColor());
    assertEquals("Wrong default border color", new Color(7, 8, 9), colorer
        .getDefaultBorderColor());
  }

  /**
   * Imports a model with only one rule, checks that all attributes of that rule
   * are correctly imported.
   */
  public void testColorImportOneRule() throws Exception
  {
    File file = new File("test/ColorImportTest_OneRule.xml");
    Colorer colorer = new Colorer();
    ColorImporter importer = new ColorImporter(colorer);
    importer.importFromFile(file);

    assertEquals("Wrong number of rules", 1, colorer.getNumberOfRules());
    ColorRule element = colorer.getColorRule(0);
    assertColorRule(element, "A test rule", new Color(0xFF, 0x10, 0x1F),
        new Color(0, 1, 2), "A test category", "A test message",
        "A test stack trace\nwith some\nlines");
  }

  /**
   * Imports a model with a single rule which has as many of its attributes as
   * possible "blanked out".
   */
  public void testColorImportRuleMissingInformation() throws Exception
  {
    File file = new File("test/ColorImportTest_RuleMissingInformation.xml");
    Colorer colorer = new Colorer();
    ColorImporter importer = new ColorImporter(colorer);
    importer.importFromFile(file);

    assertEquals("Wrong number of rules", 1, colorer.getNumberOfRules());
    ColorRule element = colorer.getColorRule(0);
    assertColorRule(element, "", new Color(0xFF, 0x10, 0x1F),
        new Color(0, 1, 2), "", "", "");
  }

  /**
   * Imports a colorer with 5 rules. Only checks that 5 rules are imported,
   * not that the contents are correct.
   */
  public void testColorImportMoreRules() throws Exception
  {
    File file = new File("test/ColorImportTest_MoreRules.xml");
    Colorer colorer = new Colorer();
    ColorImporter importer = new ColorImporter(colorer);
    importer.importFromFile(file);

    assertEquals("Wrong number of rules", 5, colorer.getNumberOfRules());
  }

  private void assertColorRule(ColorRule rule, String name, Color bar,
      Color border, String category, String message, String stackTrace)
  {
    assertEquals("Name incorrect", name, rule.getName());
    assertEquals("Bar color incorrect", bar, rule.getBarColor());
    assertEquals("Border color incorrect", border, rule.getBorderColor());
    assertEquals("Category incorrect", category, rule.getCategory());
    assertEquals("Message incorrect", message, rule.getMessage());
    assertEquals("Stack trace incorrect", stackTrace, rule.getStackTrace());
  }
}
