package performancemonster.test.instrumentation;

import java.util.Collection;

import junit.framework.TestCase;
import performancemonster.instrumentation.ClassDefinition;
import performancemonster.instrumentation.impl.DirectoryFileClassDefinition;

public class DirectoryFileClassDefinitionTest extends TestCase
{
  public static final String DIRECTORY = "release/test/classes";
  public static final String FAKEDIRECTORY = "release/XYZ"; 
  public static final String INSPECTEDCLASS = "release/test/misc/ClassToInspect.class";

  public void testLoadDirectory()
  {
    Collection<ClassDefinition> loadedClasses = DirectoryFileClassDefinition
        .analyzeDirectory(DIRECTORY);
    assertTrue("No classes could be loaded", loadedClasses.size() > 0);
  }
  
  public void testLoadFailsWithWrongDirectoryName()
  {
    Collection<ClassDefinition> loadedClasses = DirectoryFileClassDefinition
        .analyzeDirectory(FAKEDIRECTORY);
    assertEquals("No classes should be loaded", 0, loadedClasses.size());
  }
  
  public void testInspectClass()
  {
    Collection<ClassDefinition> loadedClasses = DirectoryFileClassDefinition
        .analyzeDirectory(DIRECTORY);
    ClassDefinition classToInspect = null;
    for (ClassDefinition definition : loadedClasses) {
      if (definition.getFullName().equals(
          "performancemonster.test.instrumentation.ClassToInspect")) {
        classToInspect = definition;
      }
    }
    
    assertNotNull("Did not find ClassToInspect", classToInspect);
    assertEquals("Wrong package name",
        "performancemonster.test.instrumentation", classToInspect
            .getPackageName());
    assertEquals("Wrong short class name", "ClassToInspect", classToInspect
        .getShortName());
    assertTrue("Wrong contents", new FileToBytesComparator(INSPECTEDCLASS)
        .compareToArray(classToInspect.getBytes()));
  }
}
