package performancemonster.test.instrumentation;

import java.util.Collection;

import performancemonster.instrumentation.ClassDefinition;
import performancemonster.instrumentation.impl.JarFileClassDefinition;
import junit.framework.TestCase;

public class JarFileClassDefinitionTest extends TestCase
{
  public static final String JARFILE = "release/performancemonster-test.jar";
  public static final String FAKEFILE = "release/XYZ.jar"; 
  public static final String INSPECTEDCLASS = "release/test/misc/ClassToInspect.class";

  public void testLoadJarFile()
  {
    Collection<ClassDefinition> loadedClasses = JarFileClassDefinition
        .analyzeJarFile(JARFILE);
    assertTrue("No loaded classes", loadedClasses.size() > 0);
  }
  
  public void testLoadFailsWithWrongFileName()
  {
    Collection<ClassDefinition> loadedClasses = JarFileClassDefinition
        .analyzeJarFile(FAKEFILE);
    assertEquals("No classes should be loaded", 0, loadedClasses.size());
  }
  
  public void testInspectClass()
  {
    Collection<ClassDefinition> loadedClasses = JarFileClassDefinition
    .analyzeJarFile(JARFILE);
    ClassDefinition classToInspect = null;
    for (ClassDefinition definition : loadedClasses) {
      if (definition.getFullName().equals(
          "performancemonster.test.instrumentation.ClassToInspect")) {
        classToInspect = definition;
      }
    }
    
    assertNotNull("Did not find ClassToInspect", classToInspect);
    assertEquals("Wrong package name",
        "performancemonster.test.instrumentation", classToInspect
            .getPackageName());
    assertEquals("Wrong short class name", "ClassToInspect", classToInspect
        .getShortName());
    assertTrue("Wrong contents", new FileToBytesComparator(INSPECTEDCLASS)
        .compareToArray(classToInspect.getBytes()));
  }
}
